@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Juno::Check::HTTP;
 {
-  $Juno::Check::HTTP::VERSION = '0.001';
+  $Juno::Check::HTTP::VERSION = '0.002';
 }
 # ABSTRACT: An HTTP check for Juno
 
@@ -68,7 +68,7 @@ Juno::Check::HTTP - An HTTP check for Juno
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -186,10 +186,20 @@ L<Juno> will call this method for you. You should not call it yourself.
 
 L<Juno> will call this method for you. You should not call it yourself.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Sawyer X <xsawyerx@cpan.org>
 
+=item *
+
+Adam Balali <adamba@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by Sawyer X.
